"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.conference_result import ConferenceResult
globals()['ConferenceResult'] = ConferenceResult

from freeclimb.model.conference_list_all_of import ConferenceListAllOf  # noqa: E501

class TestConferenceListAllOf(unittest.TestCase):
    """ConferenceListAllOf unit test stubs"""

    def setUp(self):
        self.model = ConferenceListAllOf(
        )
    
    def test_conferences(self):
        """Test ConferenceListAllOf.conferences"""
        testList = []
        self.model.conferences = testList
        assert self.model.get("conferences") == testList


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.application_list_all_of import ApplicationListAllOf
from freeclimb.model.application_result import ApplicationResult
from freeclimb.model.pagination_model import PaginationModel
globals()['ApplicationListAllOf'] = ApplicationListAllOf
globals()['ApplicationResult'] = ApplicationResult
globals()['PaginationModel'] = PaginationModel

from freeclimb.model.application_list import ApplicationList  # noqa: E501

class TestApplicationList(unittest.TestCase):
    """ApplicationList unit test stubs"""

    def setUp(self):
        self.model = ApplicationList(
        )
    
    def test_total(self):
        """Test ApplicationList.total"""
        self.model.total = 1
        assert self.model.get("total") == 1

    def test_start(self):
        """Test ApplicationList.start"""
        self.model.start = 1
        assert self.model.get("start") == 1

    def test_end(self):
        """Test ApplicationList.end"""
        self.model.end = 1
        assert self.model.get("end") == 1

    def test_page(self):
        """Test ApplicationList.page"""
        self.model.page = 1
        assert self.model.get("page") == 1

    def test_num_pages(self):
        """Test ApplicationList.num_pages"""
        self.model.num_pages = 1
        assert self.model.get("num_pages") == 1

    def test_page_size(self):
        """Test ApplicationList.page_size"""
        self.model.page_size = 1
        assert self.model.get("page_size") == 1

    def test_next_page_uri(self):
        """Test ApplicationList.next_page_uri"""
        self.model.next_page_uri = "TEST_STRING"
        assert self.model.get("next_page_uri") == "TEST_STRING"

    def test_applications(self):
        """Test ApplicationList.applications"""
        testList = []
        self.model.applications = testList
        assert self.model.get("applications") == testList


if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    This is a manually implemented test to validate the 
    contents of https://github.com/FreeClimbAPI/Python-Getting-Started-Tutorial/blob/master/python-getting-started.py
    are functioning as expected
"""

import unittest

import freeclimb
import json


class TestQuickStart(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPerclGeneration(self):
        message = "Hello, FreeClimb!"
        say = freeclimb.Say(text=message)
        get_speech = freeclimb.GetSpeech(
            action_url="http://example.com/actionurl/getspeech", prompts=[say], grammar_file="grammar.xml")
        record_utterance = freeclimb.RecordUtterance(
            action_url="http://example.actionurl/recordutterance", silence_timeout_ms=1000)
        script = freeclimb.PerclScript(commands=[say, get_speech, record_utterance])
        data = script.to_json()
        expected_json = json.dumps(
            [
                {
                    "Say": {
                        "text": "Hello, FreeClimb!"
                    }
                },
                {
                    "GetSpeech": {
                        "actionUrl": "http://example.com/actionurl/getspeech",
                        "grammarFile": "grammar.xml",
                        "prompts": [
                            {
                                "Say": {
                                    "text": "Hello, FreeClimb!"
                                }
                            }
                        ]
                    }
                },
                {
                    "RecordUtterance": {
                        "actionUrl": "http://example.actionurl/recordutterance",
                        "silenceTimeoutMs": 1000
                    }
                }
            ])
        self.assertEqual(data, expected_json)


if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.pagination_model import PaginationModel
from freeclimb.model.recording_list_all_of import RecordingListAllOf
from freeclimb.model.recording_result import RecordingResult
globals()['PaginationModel'] = PaginationModel
globals()['RecordingListAllOf'] = RecordingListAllOf
globals()['RecordingResult'] = RecordingResult

from freeclimb.model.recording_list import RecordingList  # noqa: E501

class TestRecordingList(unittest.TestCase):
    """RecordingList unit test stubs"""

    def setUp(self):
        self.model = RecordingList(
        )
    
    def test_total(self):
        """Test RecordingList.total"""
        self.model.total = 1
        assert self.model.get("total") == 1

    def test_start(self):
        """Test RecordingList.start"""
        self.model.start = 1
        assert self.model.get("start") == 1

    def test_end(self):
        """Test RecordingList.end"""
        self.model.end = 1
        assert self.model.get("end") == 1

    def test_page(self):
        """Test RecordingList.page"""
        self.model.page = 1
        assert self.model.get("page") == 1

    def test_num_pages(self):
        """Test RecordingList.num_pages"""
        self.model.num_pages = 1
        assert self.model.get("num_pages") == 1

    def test_page_size(self):
        """Test RecordingList.page_size"""
        self.model.page_size = 1
        assert self.model.get("page_size") == 1

    def test_next_page_uri(self):
        """Test RecordingList.next_page_uri"""
        self.model.next_page_uri = "TEST_STRING"
        assert self.model.get("next_page_uri") == "TEST_STRING"

    def test_recordings(self):
        """Test RecordingList.recordings"""
        testList = []
        self.model.recordings = testList
        assert self.model.get("recordings") == testList


if __name__ == '__main__':
    unittest.main()


import sys
import time
import unittest

from freeclimb.utils.request_verifier import RequestVerifier

class TestRequestVerifier(unittest.TestCase):
    """RequestVerifier unit test stubs"""

    def setUp(self):
        self.request_verifier = RequestVerifier()
    
    def tearDown(self):
        pass

    def test_check_request_body(self):
        request_body = ""
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Request Body cannot be empty or null")
    
    def test_check_request_header_no_signatures(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=1679944186,"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Error with request header, signatures are not present")
    
    def test_check_request_header_no_timestamp(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Error with request header, timestamp is not present")
    
    def test_check_request_header_empty_request_header(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = ""        
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Error with request header, Request header is empty")

    def test_check_signing_secret(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = ""
        tolerance = 5 * 60 * 1000
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"        
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Signing secret cannot be empty or null")
    
    def test_check_tolerance_max_int(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = sys.maxsize
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"        
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Tolerance value must be a positive integer")
    
    def test_check_tolerance_zero_value(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 0
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"        
        with self.assertRaises(Exception) as exc:
            self.request_verifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Tolerance value must be a positive integer")
    
    def test_check_tolerance_negative_value(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = -5
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"        
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Tolerance value must be a positive integer")
    
    def test_verify_tolerance(self):
        current_time = int(time.time())
        request_header_time = current_time - (6*60*1000)
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=" + str(request_header_time) + ",v1=1d798c86e977ff734dec3a8b8d67fe8621dcc1df46ef4212e0bfe2e122b01bfd,v1=78e363373f8a9f6fddc2e3ca3a1ed9dc94efa44d378363adf52434e78f32d8fb"        
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Request time exceeded tolerance threshold. Request: " + str(request_header_time)
                + ", CurrentTime: " + str(current_time) + ", tolerance: " + str(tolerance))
    
    def test_verify_signature(self):
        current_time = int(time.time())
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7794"
        tolerance = 5 * 60 * 1000
        request_header = "t=" + str(current_time) + ",v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"        
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        self.assertEqual(str(exc.exception), "Unverified signature request, If this request was unexpected, it may be from a bad actor. Please proceed with caution. If the request was exepected, please check any typos or issues with the signingSecret")
    
    def test_verify_request_signature(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=3795106129,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=96b769b34426fa69117dd6d1bda2c432beb2cf4c63dd2de495fca0c37dde82b2"        
        raised = False
        try:
            RequestVerifier.verify_request_signature(request_body, request_header, signing_secret, tolerance)
        except:
            raised = True
            self.assertFalse(raised, 'Exception has been raised')
        
    
    

if __name__ == '__main__':
    unittest.main()


# flake8: noqa

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "4.7.0"

# import ApiClient
from freeclimb.api_client import ApiClient

# import Configuration
from freeclimb.configuration import Configuration

# Utils
from freeclimb.utils.request_verifier import RequestVerifier

# import exceptions
from freeclimb.exceptions import OpenApiException
from freeclimb.exceptions import ApiAttributeError
from freeclimb.exceptions import ApiTypeError
from freeclimb.exceptions import ApiValueError
from freeclimb.exceptions import ApiKeyError
from freeclimb.exceptions import ApiException

from freeclimb.model.account_request import AccountRequest
from freeclimb.model.account_result import AccountResult
from freeclimb.model.account_result_all_of import AccountResultAllOf
from freeclimb.model.account_status import AccountStatus
from freeclimb.model.account_type import AccountType
from freeclimb.model.add_to_conference import AddToConference
from freeclimb.model.add_to_conference_all_of import AddToConferenceAllOf
from freeclimb.model.answered_by import AnsweredBy
from freeclimb.model.application_list import ApplicationList
from freeclimb.model.application_list_all_of import ApplicationListAllOf
from freeclimb.model.application_request import ApplicationRequest
from freeclimb.model.application_result import ApplicationResult
from freeclimb.model.application_result_all_of import ApplicationResultAllOf
from freeclimb.model.available_number import AvailableNumber
from freeclimb.model.available_number_list import AvailableNumberList
from freeclimb.model.available_number_list_all_of import AvailableNumberListAllOf
from freeclimb.model.buy_incoming_number_request import BuyIncomingNumberRequest
from freeclimb.model.call_direction import CallDirection
from freeclimb.model.call_list import CallList
from freeclimb.model.call_list_all_of import CallListAllOf
from freeclimb.model.call_result import CallResult
from freeclimb.model.call_result_all_of import CallResultAllOf
from freeclimb.model.call_status import CallStatus
from freeclimb.model.capabilities import Capabilities
from freeclimb.model.conference_list import ConferenceList
from freeclimb.model.conference_list_all_of import ConferenceListAllOf
from freeclimb.model.conference_participant_list import ConferenceParticipantList
from freeclimb.model.conference_participant_list_all_of import ConferenceParticipantListAllOf
from freeclimb.model.conference_participant_result import ConferenceParticipantResult
from freeclimb.model.conference_participant_result_all_of import ConferenceParticipantResultAllOf
from freeclimb.model.conference_result import ConferenceResult
from freeclimb.model.conference_result_all_of import ConferenceResultAllOf
from freeclimb.model.conference_status import ConferenceStatus
from freeclimb.model.create_conference import CreateConference
from freeclimb.model.create_conference_all_of import CreateConferenceAllOf
from freeclimb.model.create_conference_request import CreateConferenceRequest
from freeclimb.model.create_web_rtc_token import CreateWebRTCToken
from freeclimb.model.dequeue import Dequeue
from freeclimb.model.enqueue import Enqueue
from freeclimb.model.enqueue_all_of import EnqueueAllOf
from freeclimb.model.filter_logs_request import FilterLogsRequest
from freeclimb.model.get_digits import GetDigits
from freeclimb.model.get_digits_all_of import GetDigitsAllOf
from freeclimb.model.get_speech import GetSpeech
from freeclimb.model.get_speech_all_of import GetSpeechAllOf
from freeclimb.model.get_speech_reason import GetSpeechReason
from freeclimb.model.grammar_file_built_in import GrammarFileBuiltIn
from freeclimb.model.grammar_type import GrammarType
from freeclimb.model.hangup import Hangup
from freeclimb.model.hangup_all_of import HangupAllOf
from freeclimb.model.if_machine import IfMachine
from freeclimb.model.incoming_number_list import IncomingNumberList
from freeclimb.model.incoming_number_list_all_of import IncomingNumberListAllOf
from freeclimb.model.incoming_number_request import IncomingNumberRequest
from freeclimb.model.incoming_number_result import IncomingNumberResult
from freeclimb.model.incoming_number_result_all_of import IncomingNumberResultAllOf
from freeclimb.model.language import Language
from freeclimb.model.log_level import LogLevel
from freeclimb.model.log_list import LogList
from freeclimb.model.log_list_all_of import LogListAllOf
from freeclimb.model.log_result import LogResult
from freeclimb.model.machine_type import MachineType
from freeclimb.model.make_call_request import MakeCallRequest
from freeclimb.model.message_direction import MessageDirection
from freeclimb.model.message_request import MessageRequest
from freeclimb.model.message_request_all_of import MessageRequestAllOf
from freeclimb.model.message_result import MessageResult
from freeclimb.model.message_result_all_of import MessageResultAllOf
from freeclimb.model.message_status import MessageStatus
from freeclimb.model.messages_list import MessagesList
from freeclimb.model.messages_list_all_of import MessagesListAllOf
from freeclimb.model.mutable_resource_model import MutableResourceModel
from freeclimb.model.out_dial import OutDial
from freeclimb.model.out_dial_all_of import OutDialAllOf
from freeclimb.model.pagination_model import PaginationModel
from freeclimb.model.park import Park
from freeclimb.model.park_all_of import ParkAllOf
from freeclimb.model.pause import Pause
from freeclimb.model.pause_all_of import PauseAllOf
from freeclimb.model.percl_command import PerclCommand
from freeclimb.model.percl_script import PerclScript
from freeclimb.model.play import Play
from freeclimb.model.play_all_of import PlayAllOf
from freeclimb.model.play_beep import PlayBeep
from freeclimb.model.play_early_media import PlayEarlyMedia
from freeclimb.model.play_early_media_all_of import PlayEarlyMediaAllOf
from freeclimb.model.queue_list import QueueList
from freeclimb.model.queue_list_all_of import QueueListAllOf
from freeclimb.model.queue_member import QueueMember
from freeclimb.model.queue_member_list import QueueMemberList
from freeclimb.model.queue_member_list_all_of import QueueMemberListAllOf
from freeclimb.model.queue_request import QueueRequest
from freeclimb.model.queue_result import QueueResult
from freeclimb.model.queue_result_all_of import QueueResultAllOf
from freeclimb.model.queue_result_status import QueueResultStatus
from freeclimb.model.record_utterance import RecordUtterance
from freeclimb.model.record_utterance_all_of import RecordUtteranceAllOf
from freeclimb.model.record_utterance_term_reason import RecordUtteranceTermReason
from freeclimb.model.recording_list import RecordingList
from freeclimb.model.recording_list_all_of import RecordingListAllOf
from freeclimb.model.recording_result import RecordingResult
from freeclimb.model.recording_result_all_of import RecordingResultAllOf
from freeclimb.model.redirect import Redirect
from freeclimb.model.redirect_all_of import RedirectAllOf
from freeclimb.model.reject import Reject
from freeclimb.model.reject_all_of import RejectAllOf
from freeclimb.model.remove_from_conference import RemoveFromConference
from freeclimb.model.request_type import RequestType
from freeclimb.model.sms_ten_dlc_brand import SMSTenDLCBrand
from freeclimb.model.sms_ten_dlc_brands_list_result import SMSTenDLCBrandsListResult
from freeclimb.model.sms_ten_dlc_brands_list_result_all_of import SMSTenDLCBrandsListResultAllOf
from freeclimb.model.sms_ten_dlc_campaign import SMSTenDLCCampaign
from freeclimb.model.sms_ten_dlc_campaigns_list_result import SMSTenDLCCampaignsListResult
from freeclimb.model.sms_ten_dlc_campaigns_list_result_all_of import SMSTenDLCCampaignsListResultAllOf
from freeclimb.model.sms_ten_dlc_partner_campaign import SMSTenDLCPartnerCampaign
from freeclimb.model.sms_ten_dlc_partner_campaign_brand import SMSTenDLCPartnerCampaignBrand
from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result import SMSTenDLCPartnerCampaignsListResult
from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result_all_of import SMSTenDLCPartnerCampaignsListResultAllOf
from freeclimb.model.sms_toll_free_campaign import SMSTollFreeCampaign
from freeclimb.model.sms_toll_free_campaigns_list_result import SMSTollFreeCampaignsListResult
from freeclimb.model.sms_toll_free_campaigns_list_result_all_of import SMSTollFreeCampaignsListResultAllOf
from freeclimb.model.say import Say
from freeclimb.model.say_all_of import SayAllOf
from freeclimb.model.send_digits import SendDigits
from freeclimb.model.send_digits_all_of import SendDigitsAllOf
from freeclimb.model.set_listen import SetListen
from freeclimb.model.set_listen_all_of import SetListenAllOf
from freeclimb.model.set_talk import SetTalk
from freeclimb.model.set_talk_all_of import SetTalkAllOf
from freeclimb.model.sms import Sms
from freeclimb.model.sms_all_of import SmsAllOf
from freeclimb.model.start_record_call import StartRecordCall
from freeclimb.model.tfn import TFN
from freeclimb.model.terminate_conference import TerminateConference
from freeclimb.model.transcribe_utterance import TranscribeUtterance
from freeclimb.model.transcribe_utterance_all_of import TranscribeUtteranceAllOf
from freeclimb.model.transcribe_utterance_all_of_record import TranscribeUtteranceAllOfRecord
from freeclimb.model.unpark import Unpark
from freeclimb.model.update_call_request import UpdateCallRequest
from freeclimb.model.update_call_request_status import UpdateCallRequestStatus
from freeclimb.model.update_conference_participant_request import UpdateConferenceParticipantRequest
from freeclimb.model.update_conference_request import UpdateConferenceRequest
from freeclimb.model.update_conference_request_status import UpdateConferenceRequestStatus



import time, hmac, hashlib

class SignatureInformation:
    request_timestamp:int = 0
    signatures = []

    def __init__(self, request_header:str):
        signature_headers = request_header.split(",")
        for signature in signature_headers:
            header, value = signature.split("=")
            if header == "t":
                self.request_timestamp = int(value)
            elif header == "v1":
                self.signatures.append(value) 
    
    def is_request_time_valid(self, tolerance:int) -> bool:
        current_time = self.get_current_unix_time()
        time_calculation:int = self.request_timestamp + tolerance
        return current_time < (time_calculation)

    def is_signature_safe(self, requestBody:str, signingSecret:str) -> bool:
        hashValue = self.__compute_hash(requestBody, signingSecret)
        return hashValue in self.signatures

    def __compute_hash(self, requestBody:str, signingSecret:str) -> str:
        data = str(self.request_timestamp) + "." + requestBody
        return hmac.new(bytes(signingSecret, 'utf-8'), data.encode('utf-8'), digestmod=hashlib.sha256).hexdigest()

    def get_current_unix_time(self) -> int:
        return int(time.time())



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.add_to_conference_all_of import AddToConferenceAllOf  # noqa: E501

class TestAddToConferenceAllOf(unittest.TestCase):
    """AddToConferenceAllOf unit test stubs"""

    def setUp(self):
        self.model = AddToConferenceAllOf(
            conference_id="",
        )
    
    def test_allow_call_control(self):
        """Test AddToConferenceAllOf.allow_call_control"""
        self.model.allow_call_control = False
        assert self.model.get("allow_call_control") == False

    def test_call_control_sequence(self):
        """Test AddToConferenceAllOf.call_control_sequence"""
        self.model.call_control_sequence = "TEST_STRING"
        assert self.model.get("call_control_sequence") == "TEST_STRING"

    def test_call_control_url(self):
        """Test AddToConferenceAllOf.call_control_url"""
        self.model.call_control_url = "TEST_STRING"
        assert self.model.get("call_control_url") == "TEST_STRING"

    def test_conference_id(self):
        """Test AddToConferenceAllOf.conference_id"""
        self.model.conference_id = "TEST_STRING"
        assert self.model.get("conference_id") == "TEST_STRING"

    def test_leave_conference_url(self):
        """Test AddToConferenceAllOf.leave_conference_url"""
        self.model.leave_conference_url = "TEST_STRING"
        assert self.model.get("leave_conference_url") == "TEST_STRING"

    def test_listen(self):
        """Test AddToConferenceAllOf.listen"""
        self.model.listen = False
        assert self.model.get("listen") == False

    def test_notification_url(self):
        """Test AddToConferenceAllOf.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.get("notification_url") == "TEST_STRING"

    def test_start_conf_on_enter(self):
        """Test AddToConferenceAllOf.start_conf_on_enter"""
        self.model.start_conf_on_enter = False
        assert self.model.get("start_conf_on_enter") == False

    def test_talk(self):
        """Test AddToConferenceAllOf.talk"""
        self.model.talk = False
        assert self.model.get("talk") == False


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.pagination_model import PaginationModel
from freeclimb.model.sms_ten_dlc_partner_campaign import SMSTenDLCPartnerCampaign
from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result_all_of import SMSTenDLCPartnerCampaignsListResultAllOf
globals()['PaginationModel'] = PaginationModel
globals()['SMSTenDLCPartnerCampaign'] = SMSTenDLCPartnerCampaign
globals()['SMSTenDLCPartnerCampaignsListResultAllOf'] = SMSTenDLCPartnerCampaignsListResultAllOf

from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result import SMSTenDLCPartnerCampaignsListResult  # noqa: E501

class TestSMSTenDLCPartnerCampaignsListResult(unittest.TestCase):
    """SMSTenDLCPartnerCampaignsListResult unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCPartnerCampaignsListResult(
        )
    
    def test_total(self):
        """Test SMSTenDLCPartnerCampaignsListResult.total"""
        self.model.total = 1
        assert self.model.get("total") == 1

    def test_start(self):
        """Test SMSTenDLCPartnerCampaignsListResult.start"""
        self.model.start = 1
        assert self.model.get("start") == 1

    def test_end(self):
        """Test SMSTenDLCPartnerCampaignsListResult.end"""
        self.model.end = 1
        assert self.model.get("end") == 1

    def test_page(self):
        """Test SMSTenDLCPartnerCampaignsListResult.page"""
        self.model.page = 1
        assert self.model.get("page") == 1

    def test_num_pages(self):
        """Test SMSTenDLCPartnerCampaignsListResult.num_pages"""
        self.model.num_pages = 1
        assert self.model.get("num_pages") == 1

    def test_page_size(self):
        """Test SMSTenDLCPartnerCampaignsListResult.page_size"""
        self.model.page_size = 1
        assert self.model.get("page_size") == 1

    def test_next_page_uri(self):
        """Test SMSTenDLCPartnerCampaignsListResult.next_page_uri"""
        self.model.next_page_uri = "TEST_STRING"
        assert self.model.get("next_page_uri") == "TEST_STRING"

    def test_partner_campaigns(self):
        """Test SMSTenDLCPartnerCampaignsListResult.partner_campaigns"""
        testList = []
        self.model.partner_campaigns = testList
        assert self.model.get("partner_campaigns") == testList


if __name__ == '__main__':
    unittest.main()


import unittest

from freeclimb.utils.signature_information import SignatureInformation

class TestSignatureInformation(unittest.TestCase):
    """SignatureInformation unit test stubs"""

    def setUp(self):
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        self.signature_information = SignatureInformation(request_header)
    
    def tearDown(self):
        pass

    def test_is_request_time_valid_true(self):
        request_header = "t=" + str(self.signature_information.get_current_unix_time()) + ",v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        self.signature_information = SignatureInformation(request_header)
        tolerance = 5 * 60 * 1000
        self.assertEqual(self.signature_information.is_request_time_valid(tolerance), True)
    
    def test_is_request_time_valid_false(self):
        request_header = "t=" + str(self.signature_information.get_current_unix_time() - (600 * 60 * 1000)) + ",v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        self.signature_information = SignatureInformation(request_header)
        tolerance = 500 * 60 * 1000
        self.assertEqual(self.signature_information.is_request_time_valid(tolerance), False)
    
    def test_is_signature_safe_true(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        self.assertEqual(self.signature_information.is_signature_safe(request_body, signing_secret), True)

    def test_is_signature_safe_false(self):
        request_body = "{\"accountId\":\"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c\",\"callId\":\"CAccb0b00506553cda09b51c5477f672a49e0b2213\",\"callStatus\":\"ringing\",\"conferenceId\":null,\"direction\":\"inbound\",\"from\":\"+13121000109\",\"parentCallId\":null,\"queueId\":null,\"requestType\":\"inboundCall\",\"to\":\"+13121000096\"}"
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7794"
        self.assertEqual(self.signature_information.is_signature_safe(request_body, signing_secret), False)
        
    

if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.queue_result_status import QueueResultStatus  # noqa: E501

class TestQueueResultStatus(unittest.TestCase):
    """QueueResultStatus unit test stubs"""

    
    def test_QUEUE_FULL_should_serialize_to_enum(self):
        expected = QueueResultStatus.QUEUE_FULL
        calculated = QueueResultStatus['QUEUE_FULL']
        assert expected == calculated

    def test_QUEUE_FULL_should_deserialize_to_string(self):
        test = QueueResultStatus.QUEUE_FULL
        expected = "queueFull"
        calculated = test.value
        assert expected == calculated

    def test_DEQUEUED_should_serialize_to_enum(self):
        expected = QueueResultStatus.DEQUEUED
        calculated = QueueResultStatus['DEQUEUED']
        assert expected == calculated

    def test_DEQUEUED_should_deserialize_to_string(self):
        test = QueueResultStatus.DEQUEUED
        expected = "dequeued"
        calculated = test.value
        assert expected == calculated

    def test_HANGUP_should_serialize_to_enum(self):
        expected = QueueResultStatus.HANGUP
        calculated = QueueResultStatus['HANGUP']
        assert expected == calculated

    def test_HANGUP_should_deserialize_to_string(self):
        test = QueueResultStatus.HANGUP
        expected = "hangup"
        calculated = test.value
        assert expected == calculated

    def test_SYSTEM_ERROR_should_serialize_to_enum(self):
        expected = QueueResultStatus.SYSTEM_ERROR
        calculated = QueueResultStatus['SYSTEM_ERROR']
        assert expected == calculated

    def test_SYSTEM_ERROR_should_deserialize_to_string(self):
        test = QueueResultStatus.SYSTEM_ERROR
        expected = "systemError"
        calculated = test.value
        assert expected == calculated

    
if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.conference_participant_result_all_of import ConferenceParticipantResultAllOf
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['ConferenceParticipantResultAllOf'] = ConferenceParticipantResultAllOf
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.conference_participant_result import ConferenceParticipantResult  # noqa: E501

class TestConferenceParticipantResult(unittest.TestCase):
    """ConferenceParticipantResult unit test stubs"""

    def setUp(self):
        self.model = ConferenceParticipantResult(
        )
    
    def test_uri(self):
        """Test ConferenceParticipantResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test ConferenceParticipantResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test ConferenceParticipantResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test ConferenceParticipantResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_account_id(self):
        """Test ConferenceParticipantResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_conference_id(self):
        """Test ConferenceParticipantResult.conference_id"""
        self.model.conference_id = "TEST_STRING"
        assert self.model.get("conference_id") == "TEST_STRING"

    def test_call_id(self):
        """Test ConferenceParticipantResult.call_id"""
        self.model.call_id = "TEST_STRING"
        assert self.model.get("call_id") == "TEST_STRING"

    def test_talk(self):
        """Test ConferenceParticipantResult.talk"""
        self.model.talk = False
        assert self.model.get("talk") == False

    def test_listen(self):
        """Test ConferenceParticipantResult.listen"""
        self.model.listen = False
        assert self.model.get("listen") == False

    def test_start_conf_on_enter(self):
        """Test ConferenceParticipantResult.start_conf_on_enter"""
        self.model.start_conf_on_enter = False
        assert self.model.get("start_conf_on_enter") == False


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from freeclimb.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from freeclimb.exceptions import ApiAttributeError



def lazy_import():
    from freeclimb.model.grammar_type import GrammarType
    from freeclimb.model.percl_command import PerclCommand
    globals()['GrammarType'] = GrammarType
    globals()['PerclCommand'] = PerclCommand


class GetSpeechAllOf(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'action_url': (str,),  # noqa: E501
            'grammar_file': (str,),  # noqa: E501
            'grammar_type': (GrammarType,),  # noqa: E501
            'grammar_rule': (str,),  # noqa: E501
            'play_beep': (bool,),  # noqa: E501
            'prompts': ([PerclCommand],),  # noqa: E501
            'no_input_timeout_ms': (int,),  # noqa: E501
            'recognition_timeout_ms': (int,),  # noqa: E501
            'confidence_threshold': (float,),  # noqa: E501
            'sensitivity_level': (float,),  # noqa: E501
            'speech_complete_timeout_ms': (int,),  # noqa: E501
            'speech_incomplete_timeout_ms': (int,),  # noqa: E501
            'privacy_mode': (bool,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'action_url': 'actionUrl',  # noqa: E501
        'grammar_file': 'grammarFile',  # noqa: E501
        'grammar_type': 'grammarType',  # noqa: E501
        'grammar_rule': 'grammarRule',  # noqa: E501
        'play_beep': 'playBeep',  # noqa: E501
        'prompts': 'prompts',  # noqa: E501
        'no_input_timeout_ms': 'noInputTimeoutMs',  # noqa: E501
        'recognition_timeout_ms': 'recognitionTimeoutMs',  # noqa: E501
        'confidence_threshold': 'confidenceThreshold',  # noqa: E501
        'sensitivity_level': 'sensitivityLevel',  # noqa: E501
        'speech_complete_timeout_ms': 'speechCompleteTimeoutMs',  # noqa: E501
        'speech_incomplete_timeout_ms': 'speechIncompleteTimeoutMs',  # noqa: E501
        'privacy_mode': 'privacyMode',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, action_url, grammar_file, *args, **kwargs):  # noqa: E501
        """GetSpeechAllOf - a model defined in OpenAPI

        Args:
            action_url (str): When the caller has finished speaking or the command has timed out, FreeClimb will make a POST request to this URL. A PerCL response is expected to continue handling the call.
            grammar_file (str): The grammar file to use for speech recognition. If grammarType is set to URL, this attribute is specified as a download URL.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            grammar_type (GrammarType): [optional]  # noqa: E501
            grammar_rule (str): The grammar rule within the specified grammar file to use for speech recognition. This attribute is optional if `grammarType` is `URL` and ignored if `grammarType` is `BUILTIN`.. [optional]  # noqa: E501
            play_beep (bool): Indicates whether a beep should be played just before speech recognition is initiated so that the speaker can start to speak.. [optional]  # noqa: E501
            prompts ([PerclCommand]): The JSON array of PerCL commands to nest within the `GetSpeech` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the caller. This allows for playing menu options to the caller and to prompt for the expected input. These commands stop executing when the caller begins to input speech.. [optional]  # noqa: E501
            no_input_timeout_ms (int): When recognition is started and there is no speech detected for `noInputTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.. [optional]  # noqa: E501
            recognition_timeout_ms (int): When playback of prompts ends and there is no match for `recognitionTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.. [optional]  # noqa: E501
            confidence_threshold (float): When a recognition resource recognizes a spoken phrase, it associates a confidence level with that match. Parameter `confidenceThreshold` specifies what confidence level is considered a successful match. Values are between 0.0 and 1.0.. [optional]  # noqa: E501
            sensitivity_level (float): The speech recognizer supports a variable level of sound sensitivity. The sensitivityLevel attribute allows for filtering out background noise, so it is not mistaken for speech. Values are between 0.0 and 1.0 . [optional]  # noqa: E501
            speech_complete_timeout_ms (int): Parameter `speechCompleteTimeoutMs` specifies the length of silence required following user speech before the speech recognizer finalizes a result. This timeout applies when the recognizer currently has a complete match against an active grammar. Reasonable speech complete timeout values are typically in the range of 0.3 seconds to 1.0 seconds.. [optional]  # noqa: E501
            speech_incomplete_timeout_ms (int): Parameter `speechIncompleteTimeoutMs` specifies the length of silence following user speech after which a recognizer finalizes a result. This timeout applies when the speech prior to the silence is an incomplete match of all active grammars. Timeout `speechIncompleteTimeoutMs` is usually longer than `speechCompleteTimeoutMs` to allow users to pause mid-utterance.. [optional]  # noqa: E501
            privacy_mode (bool): Parameter privacyMode will not log the `text` as required by PCI compliance.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.action_url = action_url
        self.grammar_file = grammar_file
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, action_url, grammar_file, *args, **kwargs):  # noqa: E501
        """GetSpeechAllOf - a model defined in OpenAPI

        Args:
            action_url (str): When the caller has finished speaking or the command has timed out, FreeClimb will make a POST request to this URL. A PerCL response is expected to continue handling the call.
            grammar_file (str): The grammar file to use for speech recognition. If grammarType is set to URL, this attribute is specified as a download URL.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            grammar_type (GrammarType): [optional]  # noqa: E501
            grammar_rule (str): The grammar rule within the specified grammar file to use for speech recognition. This attribute is optional if `grammarType` is `URL` and ignored if `grammarType` is `BUILTIN`.. [optional]  # noqa: E501
            play_beep (bool): Indicates whether a beep should be played just before speech recognition is initiated so that the speaker can start to speak.. [optional]  # noqa: E501
            prompts ([PerclCommand]): The JSON array of PerCL commands to nest within the `GetSpeech` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the caller. This allows for playing menu options to the caller and to prompt for the expected input. These commands stop executing when the caller begins to input speech.. [optional]  # noqa: E501
            no_input_timeout_ms (int): When recognition is started and there is no speech detected for `noInputTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.. [optional]  # noqa: E501
            recognition_timeout_ms (int): When playback of prompts ends and there is no match for `recognitionTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.. [optional]  # noqa: E501
            confidence_threshold (float): When a recognition resource recognizes a spoken phrase, it associates a confidence level with that match. Parameter `confidenceThreshold` specifies what confidence level is considered a successful match. Values are between 0.0 and 1.0.. [optional]  # noqa: E501
            sensitivity_level (float): The speech recognizer supports a variable level of sound sensitivity. The sensitivityLevel attribute allows for filtering out background noise, so it is not mistaken for speech. Values are between 0.0 and 1.0 . [optional]  # noqa: E501
            speech_complete_timeout_ms (int): Parameter `speechCompleteTimeoutMs` specifies the length of silence required following user speech before the speech recognizer finalizes a result. This timeout applies when the recognizer currently has a complete match against an active grammar. Reasonable speech complete timeout values are typically in the range of 0.3 seconds to 1.0 seconds.. [optional]  # noqa: E501
            speech_incomplete_timeout_ms (int): Parameter `speechIncompleteTimeoutMs` specifies the length of silence following user speech after which a recognizer finalizes a result. This timeout applies when the speech prior to the silence is an incomplete match of all active grammars. Timeout `speechIncompleteTimeoutMs` is usually longer than `speechCompleteTimeoutMs` to allow users to pause mid-utterance.. [optional]  # noqa: E501
            privacy_mode (bool): Parameter privacyMode will not log the `text` as required by PCI compliance.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.action_url = action_url
        self.grammar_file = grammar_file
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")





"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.conference_list_all_of import ConferenceListAllOf
from freeclimb.model.conference_result import ConferenceResult
from freeclimb.model.pagination_model import PaginationModel
globals()['ConferenceListAllOf'] = ConferenceListAllOf
globals()['ConferenceResult'] = ConferenceResult
globals()['PaginationModel'] = PaginationModel

from freeclimb.model.conference_list import ConferenceList  # noqa: E501

class TestConferenceList(unittest.TestCase):
    """ConferenceList unit test stubs"""

    def setUp(self):
        self.model = ConferenceList(
        )
    
    def test_total(self):
        """Test ConferenceList.total"""
        self.model.total = 1
        assert self.model.get("total") == 1

    def test_start(self):
        """Test ConferenceList.start"""
        self.model.start = 1
        assert self.model.get("start") == 1

    def test_end(self):
        """Test ConferenceList.end"""
        self.model.end = 1
        assert self.model.get("end") == 1

    def test_page(self):
        """Test ConferenceList.page"""
        self.model.page = 1
        assert self.model.get("page") == 1

    def test_num_pages(self):
        """Test ConferenceList.num_pages"""
        self.model.num_pages = 1
        assert self.model.get("num_pages") == 1

    def test_page_size(self):
        """Test ConferenceList.page_size"""
        self.model.page_size = 1
        assert self.model.get("page_size") == 1

    def test_next_page_uri(self):
        """Test ConferenceList.next_page_uri"""
        self.model.next_page_uri = "TEST_STRING"
        assert self.model.get("next_page_uri") == "TEST_STRING"

    def test_conferences(self):
        """Test ConferenceList.conferences"""
        testList = []
        self.model.conferences = testList
        assert self.model.get("conferences") == testList


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.if_machine import IfMachine  # noqa: E501

class TestIfMachine(unittest.TestCase):
    """IfMachine unit test stubs"""

    
    def test_REDIRECT_should_serialize_to_enum(self):
        expected = IfMachine.REDIRECT
        calculated = IfMachine['REDIRECT']
        assert expected == calculated

    def test_REDIRECT_should_deserialize_to_string(self):
        test = IfMachine.REDIRECT
        expected = "redirect"
        calculated = test.value
        assert expected == calculated

    def test_HANGUP_should_serialize_to_enum(self):
        expected = IfMachine.HANGUP
        calculated = IfMachine['HANGUP']
        assert expected == calculated

    def test_HANGUP_should_deserialize_to_string(self):
        test = IfMachine.HANGUP
        expected = "hangup"
        calculated = test.value
        assert expected == calculated

    
if __name__ == '__main__':
    unittest.main()


import sys

from freeclimb.utils.signature_information import SignatureInformation

class RequestVerifier:
    
    DEFAULT_TOLERANCE = 5*60*1000

    @staticmethod
    def verify_request_signature(request_body:str, request_header:str, signing_secret:str, tolerance:int=DEFAULT_TOLERANCE):
        verifier = RequestVerifier()
        verifier.__check_request_body(request_body)
        verifier.__check_request_header(request_header)
        verifier.__check_signing_secret(signing_secret)
        verifier.__check_tolerance(tolerance)
        info = SignatureInformation(request_header)
        verifier.__verify_tolerance(info, tolerance)
        verifier.__verify_signature(info, request_body, signing_secret)
    
    def __check_request_body(self, request_body:str):
        if request_body == "" or request_body == None:
            raise Exception("Request Body cannot be empty or null")

    def __check_request_header(self, request_header:str): 
        if request_header == "" or request_header == None: 
            raise Exception("Error with request header, Request header is empty")
        
        elif not("t" in request_header) :
            raise Exception("Error with request header, timestamp is not present")
        
        elif not("v1" in request_header) :
            raise Exception("Error with request header, signatures are not present")
        

    def __check_signing_secret(self, signing_secret:str):
        if signing_secret == "" or signing_secret == None:
            raise Exception("Signing secret cannot be empty or null")
        
    def __check_tolerance(self, tolerance:int):
        if tolerance <= 0 or tolerance >= sys.maxsize:
            raise Exception("Tolerance value must be a positive integer")
        
    def __verify_tolerance(self, info:SignatureInformation, tolerance:int):
        currentTime = info.get_current_unix_time()
        if not(info.is_request_time_valid(tolerance)):
            raise Exception("Request time exceeded tolerance threshold. Request: " + str(info.request_timestamp)
            + ", CurrentTime: " + str(currentTime) + ", tolerance: " + str(tolerance))

    def __verify_signature(self, info:SignatureInformation, request_body:str, signing_secret:str):
         if not(info.is_signature_safe(request_body, signing_secret)):
            raise Exception("Unverified signature request, If this request was unexpected, it may be from a bad actor. Please proceed with caution. If the request was exepected, please check any typos or issues with the signingSecret")




"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.percl_command import PerclCommand
globals()['PerclCommand'] = PerclCommand

from freeclimb.model.get_digits_all_of import GetDigitsAllOf  # noqa: E501

class TestGetDigitsAllOf(unittest.TestCase):
    """GetDigitsAllOf unit test stubs"""

    def setUp(self):
        self.model = GetDigitsAllOf(
            action_url="",
        )
    
    def test_action_url(self):
        """Test GetDigitsAllOf.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.get("action_url") == "TEST_STRING"

    def test_digit_timeout_ms(self):
        """Test GetDigitsAllOf.digit_timeout_ms"""
        self.model.digit_timeout_ms = 1
        assert self.model.get("digit_timeout_ms") == 1

    def test_finish_on_key(self):
        """Test GetDigitsAllOf.finish_on_key"""
        self.model.finish_on_key = "TEST_STRING"
        assert self.model.get("finish_on_key") == "TEST_STRING"

    def test_flush_buffer(self):
        """Test GetDigitsAllOf.flush_buffer"""
        self.model.flush_buffer = False
        assert self.model.get("flush_buffer") == False

    def test_initial_timeout_ms(self):
        """Test GetDigitsAllOf.initial_timeout_ms"""
        self.model.initial_timeout_ms = 1
        assert self.model.get("initial_timeout_ms") == 1

    def test_max_digits(self):
        """Test GetDigitsAllOf.max_digits"""
        self.model.max_digits = 1
        assert self.model.get("max_digits") == 1

    def test_min_digits(self):
        """Test GetDigitsAllOf.min_digits"""
        self.model.min_digits = 1
        assert self.model.get("min_digits") == 1

    def test_prompts(self):
        """Test GetDigitsAllOf.prompts"""
        testList = []
        self.model.prompts = testList
        assert self.model.get("prompts") == testList

    def test_privacy_mode(self):
        """Test GetDigitsAllOf.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.get("privacy_mode") == False


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.message_result_all_of import MessageResultAllOf
from freeclimb.model.message_status import MessageStatus
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['MessageResultAllOf'] = MessageResultAllOf
globals()['MessageStatus'] = MessageStatus
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.message_result import MessageResult  # noqa: E501

class TestMessageResult(unittest.TestCase):
    """MessageResult unit test stubs"""

    def setUp(self):
        self.model = MessageResult(
        )
    
    def test_uri(self):
        """Test MessageResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test MessageResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test MessageResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test MessageResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_account_id(self):
        """Test MessageResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_message_id(self):
        """Test MessageResult.message_id"""
        self.model.message_id = "TEST_STRING"
        assert self.model.get("message_id") == "TEST_STRING"

    def test_status(self):
        """Test MessageResult.status"""
        self.model.status = MessageStatus.NEW
        assert self.model.get("status") == MessageStatus.NEW
        self.model.status = MessageStatus.QUEUED
        assert self.model.get("status") == MessageStatus.QUEUED
        self.model.status = MessageStatus.REJECTED
        assert self.model.get("status") == MessageStatus.REJECTED
        self.model.status = MessageStatus.SENDING
        assert self.model.get("status") == MessageStatus.SENDING
        self.model.status = MessageStatus.SENT
        assert self.model.get("status") == MessageStatus.SENT
        self.model.status = MessageStatus.FAILED
        assert self.model.get("status") == MessageStatus.FAILED
        self.model.status = MessageStatus.RECEIVED
        assert self.model.get("status") == MessageStatus.RECEIVED
        self.model.status = MessageStatus.UNDELIVERED
        assert self.model.get("status") == MessageStatus.UNDELIVERED
        self.model.status = MessageStatus.EXPIRED
        assert self.model.get("status") == MessageStatus.EXPIRED
        self.model.status = MessageStatus.DELETED
        assert self.model.get("status") == MessageStatus.DELETED
        self.model.status = MessageStatus.UNKNOWN
        assert self.model.get("status") == MessageStatus.UNKNOWN

    def test__from(self):
        """Test MessageResult._from"""
        self.model._from = "TEST_STRING"
        assert self.model.get("_from") == "TEST_STRING"

    def test_to(self):
        """Test MessageResult.to"""
        self.model.to = "TEST_STRING"
        assert self.model.get("to") == "TEST_STRING"

    def test_text(self):
        """Test MessageResult.text"""
        self.model.text = "TEST_STRING"
        assert self.model.get("text") == "TEST_STRING"

    def test_direction(self):
        """Test MessageResult.direction"""
        self.model.direction = "TEST_STRING"
        assert self.model.get("direction") == "TEST_STRING"

    def test_notification_url(self):
        """Test MessageResult.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.get("notification_url") == "TEST_STRING"

    def test_brand_id(self):
        """Test MessageResult.brand_id"""
        self.model.brand_id = "TEST_STRING"
        assert self.model.get("brand_id") == "TEST_STRING"

    def test_campaign_id(self):
        """Test MessageResult.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_segment_count(self):
        """Test MessageResult.segment_count"""
        
        
        self.model.segment_count = float(1) 
        assert self.model.get("segment_count") == float(1)
        

    def test_media_urls(self):
        """Test MessageResult.media_urls"""
        testList = []
        self.model.media_urls = testList
        assert self.model.get("media_urls") == testList


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.sms_toll_free_campaign import SMSTollFreeCampaign  # noqa: E501

class TestSMSTollFreeCampaign(unittest.TestCase):
    """SMSTollFreeCampaign unit test stubs"""

    def setUp(self):
        self.model = SMSTollFreeCampaign(
            account_id="",
            campaign_id="",
            use_case="",
            registration_status="UNREGISTERED",
            date_created="",
            date_updated="",
            revision=1,
        )
    
    def test_account_id(self):
        """Test SMSTollFreeCampaign.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_campaign_id(self):
        """Test SMSTollFreeCampaign.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_use_case(self):
        """Test SMSTollFreeCampaign.use_case"""
        self.model.use_case = "TEST_STRING"
        assert self.model.get("use_case") == "TEST_STRING"

    def test_registration_status(self):
        """Test SMSTollFreeCampaign.registration_status"""
        self.model.registration_status = "UNREGISTERED"
        assert self.model.get("registration_status") == "UNREGISTERED"
        self.model.registration_status = "INITIATED"
        assert self.model.get("registration_status") == "INITIATED"
        self.model.registration_status = "PENDING"
        assert self.model.get("registration_status") == "PENDING"
        self.model.registration_status = "DECLINED"
        assert self.model.get("registration_status") == "DECLINED"
        self.model.registration_status = "REGISTERED"
        assert self.model.get("registration_status") == "REGISTERED"

    def test_registration_status_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.registration_status = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
        
    def test_date_created(self):
        """Test SMSTollFreeCampaign.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test SMSTollFreeCampaign.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test SMSTollFreeCampaign.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1


if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.call_status import CallStatus  # noqa: E501

class TestCallStatus(unittest.TestCase):
    """CallStatus unit test stubs"""

    
    def test_QUEUED_should_serialize_to_enum(self):
        expected = CallStatus.QUEUED
        calculated = CallStatus['QUEUED']
        assert expected == calculated

    def test_QUEUED_should_deserialize_to_string(self):
        test = CallStatus.QUEUED
        expected = "queued"
        calculated = test.value
        assert expected == calculated

    def test_RINGING_should_serialize_to_enum(self):
        expected = CallStatus.RINGING
        calculated = CallStatus['RINGING']
        assert expected == calculated

    def test_RINGING_should_deserialize_to_string(self):
        test = CallStatus.RINGING
        expected = "ringing"
        calculated = test.value
        assert expected == calculated

    def test_IN_PROGRESS_should_serialize_to_enum(self):
        expected = CallStatus.IN_PROGRESS
        calculated = CallStatus['IN_PROGRESS']
        assert expected == calculated

    def test_IN_PROGRESS_should_deserialize_to_string(self):
        test = CallStatus.IN_PROGRESS
        expected = "inProgress"
        calculated = test.value
        assert expected == calculated

    def test_CANCELED_should_serialize_to_enum(self):
        expected = CallStatus.CANCELED
        calculated = CallStatus['CANCELED']
        assert expected == calculated

    def test_CANCELED_should_deserialize_to_string(self):
        test = CallStatus.CANCELED
        expected = "canceled"
        calculated = test.value
        assert expected == calculated

    def test_COMPLETED_should_serialize_to_enum(self):
        expected = CallStatus.COMPLETED
        calculated = CallStatus['COMPLETED']
        assert expected == calculated

    def test_COMPLETED_should_deserialize_to_string(self):
        test = CallStatus.COMPLETED
        expected = "completed"
        calculated = test.value
        assert expected == calculated

    def test_FAILED_should_serialize_to_enum(self):
        expected = CallStatus.FAILED
        calculated = CallStatus['FAILED']
        assert expected == calculated

    def test_FAILED_should_deserialize_to_string(self):
        test = CallStatus.FAILED
        expected = "failed"
        calculated = test.value
        assert expected == calculated

    def test_BUSY_should_serialize_to_enum(self):
        expected = CallStatus.BUSY
        calculated = CallStatus['BUSY']
        assert expected == calculated

    def test_BUSY_should_deserialize_to_string(self):
        test = CallStatus.BUSY
        expected = "busy"
        calculated = test.value
        assert expected == calculated

    def test_NO_ANSWER_should_serialize_to_enum(self):
        expected = CallStatus.NO_ANSWER
        calculated = CallStatus['NO_ANSWER']
        assert expected == calculated

    def test_NO_ANSWER_should_deserialize_to_string(self):
        test = CallStatus.NO_ANSWER
        expected = "noAnswer"
        calculated = test.value
        assert expected == calculated

    
if __name__ == '__main__':
    unittest.main()


"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.account_status import AccountStatus
from freeclimb.model.account_type import AccountType
globals()['AccountStatus'] = AccountStatus
globals()['AccountType'] = AccountType

from freeclimb.model.account_result_all_of import AccountResultAllOf  # noqa: E501

class TestAccountResultAllOf(unittest.TestCase):
    """AccountResultAllOf unit test stubs"""

    def setUp(self):
        self.model = AccountResultAllOf(
        )
    
    def test_account_id(self):
        """Test AccountResultAllOf.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_api_key(self):
        """Test AccountResultAllOf.api_key"""
        self.model.api_key = "TEST_STRING"
        assert self.model.get("api_key") == "TEST_STRING"

    def test_alias(self):
        """Test AccountResultAllOf.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_label(self):
        """Test AccountResultAllOf.label"""
        self.model.label = "TEST_STRING"
        assert self.model.get("label") == "TEST_STRING"

    def test_type(self):
        """Test AccountResultAllOf.type"""
        self.model.type = AccountType.TRIAL
        assert self.model.get("type") == AccountType.TRIAL
        self.model.type = AccountType.FULL
        assert self.model.get("type") == AccountType.FULL

    def test_status(self):
        """Test AccountResultAllOf.status"""
        self.model.status = AccountStatus.CLOSED
        assert self.model.get("status") == AccountStatus.CLOSED
        self.model.status = AccountStatus.SUSPENDED
        assert self.model.get("status") == AccountStatus.SUSPENDED
        self.model.status = AccountStatus.ACTIVE
        assert self.model.get("status") == AccountStatus.ACTIVE

    def test_subresource_uris(self):
        """Test AccountResultAllOf.subresource_uris"""
        testObject = {}
        self.model.subresource_uris = testObject
        assert self.model.get("subresource_uris") == testObject


if __name__ == '__main__':
    unittest.main()